DROP PROCEDURE IF EXISTS sp_insert_financial_years;
DELIMITER $$
CREATE PROCEDURE sp_insert_financial_years(
	in vdat_start datetime,
	in vdat_end datetime,
	in vysn_current int(11),
	in vint_reactor_count int(11),
	in vint_coulumn_count int(11),
	in vint_drum_count int(11),
	in vint_purchase_count int(11),
	in vint_sale_count int(11),
	in vint_batch_no_count int(11),
	out vintReturn INT)
BEGIN
	DECLARE int_next_id int;
	DECLARE int_fy int;
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
	SELECT (ifnull(MAX(int_financial_year_id),0)+1) into int_next_id FROM tbl_financial_years;
	INSERT INTO tbl_financial_years(
	int_financial_year_id, dat_start, dat_end, ysn_current, int_reactor_count, int_coulumn_count, int_drum_count, int_purchase_count, int_sale_count, int_batch_no_count)
	 VALUES (
	int_next_id, vdat_start, vdat_end, vysn_current, vint_reactor_count, vint_coulumn_count, vint_drum_count, vint_purchase_count, vint_sale_count, vint_batch_no_count);
	COMMIT;
SET vintReturn = int_next_id;
SELECT vintReturn;
END$$
DELIMITER ;

DROP PROCEDURE IF EXISTS sp_update_financial_years;
DELIMITER $$
CREATE PROCEDURE sp_update_financial_years(
	in vint_financial_year_id int(11),
	in vdat_start datetime,
	in vdat_end datetime,
	in vysn_current int(11),
	in vint_reactor_count int(11),
	in vint_coulumn_count int(11),
	in vint_drum_count int(11),
	in vint_purchase_count int(11),
	in vint_sale_count int(11),
	in vint_batch_no_count int(11),
	out vintReturn INT)
BEGIN
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
	UPDATE tbl_financial_years set
		dat_start=vdat_start, dat_end=vdat_end, ysn_current=vysn_current, int_reactor_count=vint_reactor_count, int_coulumn_count=vint_coulumn_count, int_drum_count=vint_drum_count, int_purchase_count=vint_purchase_count, int_sale_count=vint_sale_count, int_batch_no_count= vint_batch_no_count
	WHERE int_financial_year_id=vint_financial_year_id;
	COMMIT;
	SET vintReturn = vint_financial_year_id;
	SELECT vintReturn;
END$$
DELIMITER ;

DROP PROCEDURE IF EXISTS sp_delete_financial_years;
DELIMITER $$
CREATE PROCEDURE sp_delete_financial_years(
	in vint_financial_year_id INT,
	out vintReturn INT)
BEGIN
	DECLARE int_ref_count int;
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
		DELETE FROM tbl_financial_years WHERE int_financial_year_id=vint_financial_year_id;
		SET vintReturn = vint_financial_year_id;
	COMMIT;
	SELECT vintReturn;
END$$
DELIMITER ;
