DROP PROCEDURE IF EXISTS sp_insert_production;
DELIMITER $$
CREATE PROCEDURE sp_insert_production(
	in vint_production_unit_id int(11),
	in vtxt_batch_no varchar(25),
	in vdat_start date,
	in vdat_end date,
	in vtxt_remarks varchar(250),
	in vint_by_user_id int(11),
	out vintReturn INT)
BEGIN
	DECLARE int_next_id int;
	DECLARE int_fy int;
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
	SELECT (ifnull(MAX(int_production_id),0)+1) into int_next_id FROM tbl_production;
	INSERT INTO tbl_production(
	int_production_id, int_production_unit_id, txt_batch_no, dat_start, dat_end, txt_remarks, int_by_user_id, dat_created, dat_modified)
	 VALUES (
	int_next_id, vint_production_unit_id, vtxt_batch_no, vdat_start, vdat_end, vtxt_remarks, vint_by_user_id, NOW(), NOW());
	COMMIT;
SET vintReturn = int_next_id;
SELECT vintReturn;
END$$
DELIMITER ;

DROP PROCEDURE IF EXISTS sp_update_production;
DELIMITER $$
CREATE PROCEDURE sp_update_production(
	in vint_production_id int(11),
	in vint_production_unit_id int(11),
	in vtxt_batch_no varchar(25),
	in vdat_start date,
	in vdat_end date,
	in vtxt_remarks varchar(250),
	in vint_by_user_id int(11),
	out vintReturn INT)
BEGIN
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
	UPDATE tbl_production set
		int_production_unit_id=vint_production_unit_id, txt_batch_no=vtxt_batch_no, dat_start=vdat_start, dat_end=vdat_end, txt_remarks=vtxt_remarks, int_by_user_id=vint_by_user_id,  dat_modified= NOW()
	WHERE int_production_id=vint_production_id;
	COMMIT;
	SET vintReturn = vint_production_id;
	SELECT vintReturn;
END$$
DELIMITER ;

DROP PROCEDURE IF EXISTS sp_delete_production;
DELIMITER $$
CREATE PROCEDURE sp_delete_production(
	in vint_production_id INT,
	out vintReturn INT)
BEGIN
	DECLARE int_ref_count int;
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
		SELECT SUM(int_count) INTO int_ref_count FROM (
		(Select count(int_source_production_id) AS int_count FROM tbl_stock_movement WHERE int_source_production_id=vint_production_id)
		 UNION ALL
		(Select count(int_target_production_id) AS int_count FROM tbl_stock_movement WHERE int_target_production_id=vint_production_id)
		 ) qry; 
		IF(int_ref_count> 0) THEN 
			SET vintReturn = 0;
		ELSE 
			DELETE FROM tbl_production WHERE int_production_id=vint_production_id;
			SET vintReturn = vint_production_id;
		END IF;
	COMMIT;
	SELECT vintReturn;
END$$
DELIMITER ;
