DROP PROCEDURE IF EXISTS sp_insert_production_units;
DELIMITER $$
CREATE PROCEDURE sp_insert_production_units(
	in vtxt_production_unit varchar(100),
	in vtxt_production_unit_type varchar(50),
	in vint_by_user_id int(11),
	in vdat_created datetime,
	in vdat_modified datetime,
	out vintReturn INT)
BEGIN
	DECLARE int_next_id int;
	DECLARE int_fy int;
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
	SELECT (ifnull(MAX(int_production_unit_id),0)+1) into int_next_id FROM tbl_production_units;
	INSERT INTO tbl_production_units(
	int_production_unit_id, txt_production_unit, txt_production_unit_type, int_by_user_id, dat_created, dat_modified)
	 VALUES (
	int_next_id, vtxt_production_unit, vtxt_production_unit_type, vint_by_user_id, vdat_created, vdat_modified);
	COMMIT;
SET vintReturn = int_next_id;
SELECT vintReturn;
END$$
DELIMITER ;

DROP PROCEDURE IF EXISTS sp_update_production_units;
DELIMITER $$
CREATE PROCEDURE sp_update_production_units(
	in vint_production_unit_id int(11),
	in vtxt_production_unit varchar(100),
	in vtxt_production_unit_type varchar(50),
	in vint_by_user_id int(11),
	in vdat_created datetime,
	in vdat_modified datetime,
	out vintReturn INT)
BEGIN
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
	UPDATE tbl_production_units set
		txt_production_unit=vtxt_production_unit, txt_production_unit_type=vtxt_production_unit_type, int_by_user_id=vint_by_user_id, dat_created=vdat_created, dat_modified= vdat_modified
	WHERE int_production_unit_id=vint_production_unit_id;
	COMMIT;
	SET vintReturn = vint_production_unit_id;
	SELECT vintReturn;
END$$
DELIMITER ;

DROP PROCEDURE IF EXISTS sp_delete_production_units;
DELIMITER $$
CREATE PROCEDURE sp_delete_production_units(
	in vint_production_unit_id INT,
	out vintReturn INT)
BEGIN
	DECLARE int_ref_count int;
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
		SELECT SUM(int_count) INTO int_ref_count FROM (
		(Select count(int_production_unit_id) AS int_count FROM tbl_production WHERE int_production_unit_id=vint_production_unit_id)
		 ) qry; 
		IF(int_ref_count> 0) THEN 
			SET vintReturn = 0;
		ELSE 
			DELETE FROM tbl_production_units WHERE int_production_unit_id=vint_production_unit_id;
			SET vintReturn = vint_production_unit_id;
		END IF;
	COMMIT;
	SELECT vintReturn;
END$$
DELIMITER ;
