DROP PROCEDURE IF EXISTS sp_insert_purchase_order;
DELIMITER $$
CREATE PROCEDURE sp_insert_purchase_order(
	in vdat_transaction date,
	in vint_party_id int(11),
	in vint_product_id int(11),
	in vint_agent_party_id int(11),
	in vtxt_party_document_no varchar(100),
	in vdec_rate decimal(15,2),
	in vdec_total_gross_weight decimal(15,3),
	in vdec_total_tare_weight decimal(15,3),
	in vdec_total_net_weight decimal(15,3),
	in vdec_total_product_value decimal(15,2),
	in vdec_total_freight_value decimal(15,2),
	in vdec_total_tax_value decimal(15,2),
	in vtxt_remarks varchar(250),
	in vint_by_user_id int(11),
	out vintReturn INT)
BEGIN
	DECLARE int_next_id int;
	DECLARE int_next_number int;
	DECLARE txt_next_formatted_number varchar(25);
	DECLARE int_fy int;
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
	SELECT (ifnull(MAX(int_purchase_order_id),0)+1) into int_next_id FROM tbl_purchase_order;
	
	SELECT (ifnull(MAX(int_number),0)+1) into int_next_number FROM tbl_purchase_order;
	
	SELECT YEAR(DATE_SUB(vdat_transaction,INTERVAL -3 MONTH)) into int_fy;
	Select concat( int_fy, '-',right((int_fy+1) ,2),'/',int_next_number)  into txt_next_formatted_number;
	INSERT INTO tbl_purchase_order(
	int_purchase_order_id, dat_transaction, int_number, txt_formatted_number, int_party_id, int_product_id, int_agent_party_id, txt_party_document_no, dec_rate, dec_total_gross_weight, dec_total_tare_weight, dec_total_net_weight, dec_total_product_value, dec_total_freight_value, dec_total_tax_value, txt_remarks, int_by_user_id, dat_created, dat_modified)
	 VALUES (
	int_next_id, vdat_transaction, int_next_number, txt_next_formatted_number, vint_party_id, vint_product_id, vint_agent_party_id, vtxt_party_document_no, vdec_rate, vdec_total_gross_weight, vdec_total_tare_weight, vdec_total_net_weight, vdec_total_product_value, vdec_total_freight_value, vdec_total_tax_value, vtxt_remarks, vint_by_user_id, NOW(), NOW());
	COMMIT;
SET vintReturn = int_next_id;
SELECT vintReturn;
END$$
DELIMITER ;

DROP PROCEDURE IF EXISTS sp_update_purchase_order;
DELIMITER $$
CREATE PROCEDURE sp_update_purchase_order(
	in vint_purchase_order_id int(11),
	in vdat_transaction date,
	in vint_number int(11),
	in vtxt_formatted_number varchar(25),
	in vint_party_id int(11),
	in vint_product_id int(11),
	in vint_agent_party_id int(11),
	in vtxt_party_document_no varchar(100),
	in vdec_rate decimal(15,2),
	in vdec_total_gross_weight decimal(15,3),
	in vdec_total_tare_weight decimal(15,3),
	in vdec_total_net_weight decimal(15,3),
	in vdec_total_product_value decimal(15,2),
	in vdec_total_freight_value decimal(15,2),
	in vdec_total_tax_value decimal(15,2),
	in vtxt_remarks varchar(250),
	in vint_by_user_id int(11),
	out vintReturn INT)
BEGIN
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
	UPDATE tbl_purchase_order set
		dat_transaction=vdat_transaction,  int_party_id=vint_party_id, int_product_id=vint_product_id, int_agent_party_id=vint_agent_party_id, txt_party_document_no=vtxt_party_document_no, dec_rate=vdec_rate, dec_total_gross_weight=vdec_total_gross_weight, dec_total_tare_weight=vdec_total_tare_weight, dec_total_net_weight=vdec_total_net_weight, dec_total_product_value=vdec_total_product_value, dec_total_freight_value=vdec_total_freight_value, dec_total_tax_value=vdec_total_tax_value, txt_remarks=vtxt_remarks, int_by_user_id=vint_by_user_id, dat_modified= NOW()
	WHERE int_purchase_order_id=vint_purchase_order_id;
	COMMIT;
	SET vintReturn = vint_purchase_order_id;
	SELECT vintReturn;
END$$
DELIMITER ;

DROP PROCEDURE IF EXISTS sp_delete_purchase_order;
DELIMITER $$
CREATE PROCEDURE sp_delete_purchase_order(
	in vint_purchase_order_id INT,
	out vintReturn INT)
BEGIN
	DECLARE int_ref_count int;
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
		SELECT SUM(int_count) INTO int_ref_count FROM (
		(Select count(int_source_purchase_id) AS int_count FROM tbl_stock_movement WHERE int_source_purchase_id=vint_purchase_order_id)
		 UNION ALL
		(Select count(int_target_purchase_id) AS int_count FROM tbl_stock_movement WHERE int_target_purchase_id=vint_purchase_order_id)
		 UNION ALL
		(Select count(int_purchase_order_id) AS int_count FROM tbl_purchase_order_detail WHERE int_purchase_order_id=vint_purchase_order_id)
		 UNION ALL
		(Select count(int_purchase_order_id) AS int_count FROM tbl_purchase_order_status WHERE int_purchase_order_id=vint_purchase_order_id)
		 ) qry; 
		IF(int_ref_count> 0) THEN 
			SET vintReturn = 0;
		ELSE 
			DELETE FROM tbl_purchase_order WHERE int_purchase_order_id=vint_purchase_order_id;
			SET vintReturn = vint_purchase_order_id;
		END IF;
	COMMIT;
	SELECT vintReturn;
END$$
DELIMITER ;
